@@ -100,13 +100,4 @@ from .visufunc import (
     azeqview,
 )
 from .zoomtool import mollzoom, set_g_clim
-from .fitsfunc import (
-    write_map,
-    read_map,
-    mrdfits,
-    mwrfits,
-    read_alm,
-    write_alm,
-    write_cl,
-    read_cl,
-)
+from .fitsfunc import write_map, read_map, read_alm, write_alm, write_cl, read_cl
