@@ -22,7 +22,11 @@
 from __future__ import division
 
 import six
+import sys
 import warnings
+
+if sys.version >= "3.4":
+    import pathlib
 import astropy.io.fits as pf
 import numpy as np
 
@@ -48,7 +52,7 @@ def read_cl(filename, dtype=np.float64, h=False):
 
     Parameters
     ----------
-    filename : str or HDUList or HDU
+    filename : str or HDUList or HDU or pathlib.Path instance
       the fits file name
     dtype : data type, optional
       the data type of the returned array
@@ -277,7 +281,7 @@ def read_map(
 
     Parameters
     ----------
-    filename : str or HDU or HDUList
+    filename : str or HDU or HDUList or pathlib.Path instance
       the fits file name
     field : int or tuple of int, or None, optional
       The column to read. Default: 0.
@@ -290,6 +294,7 @@ def read_map(
       Force the conversion to some type. Passing a list allows different
       types for each field. In that case, the length of the list must
       correspond to the length of the field parameter. Default: np.float64
+      if None, keep the dtype of the input FITS file
     nest : bool, optional
       If True return the map in NEST ordering, otherwise in RING ordering;
       use fits keyword ORDERING to decide whether conversion is needed or not
@@ -393,15 +398,21 @@ def read_map(
 
     for ff, curr_dtype in zip(field, dtype):
         try:
-            m = fits_hdu.data.field(ff).astype(curr_dtype, copy=False).ravel()
+            if curr_dtype is None:
+                m = fits_hdu.data.field(ff).ravel()
+            else:
+                m = fits_hdu.data.field(ff).astype(curr_dtype, copy=False).ravel()
         except pf.VerifyError as e:
             print(e)
             print("Trying to fix a badly formatted header")
             m = fits_hdu.verify("fix")
-            m = fits_hdu.data.field(ff).astype(curr_dtype, copy=False).ravel()
+            if curr_dtype is None:
+                m = fits_hdu.data.field(ff).ravel()
+            else:
+                m = fits_hdu.data.field(ff).astype(curr_dtype, copy=False).ravel()
 
         if partial:
-            mnew = UNSEEN * np.ones(sz, dtype=curr_dtype)
+            mnew = UNSEEN * np.ones(sz, dtype=m.dtype)
             mnew[pix] = m
             m = mnew
 
@@ -543,7 +554,7 @@ def read_alm(filename, hdu=1, return_mmax=False):
 
     Parameters
     ----------
-    filename : str or HDUList or HDU
+    filename : str or HDUList or HDU or pathlib.Path instance
       The name of the fits file to read
     hdu : int, or tuple of int, optional
       The header to read. Start at 0. Default: hdu=1
@@ -559,7 +570,7 @@ def read_alm(filename, hdu=1, return_mmax=False):
     lmaxtot = None
     mmaxtot = None
     for unit in np.atleast_1d(hdu):
-        idx, almr, almi = mrdfits(filename, hdu=unit)
+        idx, almr, almi = [_get_hdu(filename, hdu=unit).data.field(i) for i in range(3)]
         l = np.floor(np.sqrt(idx - 1)).astype(np.long)
         m = idx - l ** 2 - l - 1
         if (m < 0).any():
@@ -607,8 +618,11 @@ def _get_hdu(input_data, hdu=None, memmap=None):
     fits_hdu : HDU
         The extracted HDU
     """
+    allowed_paths = tuple(six.string_types)
+    if sys.version >= "3.4":
+        allowed_paths += (pathlib.Path, pathlib.PosixPath)
 
-    if isinstance(input_data, six.string_types):
+    if isinstance(input_data, allowed_paths):
         hdulist = pf.open(input_data, memmap=memmap)
         return _get_hdu(hdulist, hdu=hdu)
 
@@ -624,72 +638,12 @@ def _get_hdu(input_data, hdu=None, memmap=None):
         fits_hdu = input_data
     else:
         raise TypeError(
-            "First argument should be a input_data, HDUList instance, or HDU instance"
+            "First argument should be a input_data (str or pathlib.Path), HDUList instance, or HDU instance"
         )
 
     return fits_hdu
 
 
-def mrdfits(filename, hdu=1):
-    """
-    Read a table in a fits file.
-
-    Parameters
-    ----------
-    filename : str or HDUList or HDU
-      The name of the fits file to read, or an HDUList or HDU instance.
-    hdu : int, optional
-      The header to read. Start at 0. Default: hdu=1
-
-    Returns
-    -------
-    cols : a list of arrays
-      A list of column data in the given header
-    """
-    fits_hdu = _get_hdu(filename, hdu=hdu)
-    val = []
-    for i in range(len(fits_hdu.columns)):
-        val.append(fits_hdu.data.field(i))
-    return val
-
-
-def mwrfits(filename, data, hdu=1, colnames=None, keys=None):
-    """Write columns to a fits file in a table extension.
-
-    Parameters
-    ----------
-    filename : str
-      The fits file name
-    data : list of 1D arrays
-      A list of 1D arrays to write in the table
-    hdu : int, optional
-      The header where to write the data. Default: 1
-    colnames : list of str
-      The column names
-    keys : dict-like
-      A dictionary with keywords to write in the header
-    """
-    # Check the inputs
-    if colnames is not None:
-        if len(colnames) != len(data):
-            raise ValueError("colnames and data must the same length")
-    else:
-        colnames = [""] * len(data)
-    cols = []
-    for line in six.moves.xrange(len(data)):
-        cols.append(
-            pf.Column(
-                name=colnames[line], format=getformat(data[line]), array=data[line]
-            )
-        )
-    tbhdu = pf.BinTableHDU.from_columns(cols)
-    if type(keys) is dict:
-        for k, v in keys.items():
-            tbhdu.header[k] = v
-    # write the file
-    tbhdu.writeto(filename)
-
-
 def getformat(t):
     """Get the FITS convention format string of data type t.
 
